---
title: <span class="badge object-type-scalar"></span> Percent
---
# <span class="badge object-type-scalar"></span> Percent

Percent (0-100)

## Definition

```python
# Percent (0-100)
Percent: typing.Literal["percent"] = "percent"
```
